@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2022-01-28 10:57:09
+@LastEditTime: 2022-06-01 11:15:38
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -267,7 +267,7 @@ class CumulativeSignHandler(ClientBaseHandler):
 
 class InviteNewUserHandler(ClientBaseHandler):
     """
-    :description: 处理邀请新用户任务
+    :description: 处理邀请用户任务
     """
     @filter_check_params("act_id,tb_user_id,invite_user_id,login_token")
     def get_async(self):
@@ -299,7 +299,7 @@ class InviteNewUserHandler(ClientBaseHandler):
         check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         close_invite_limit = invoke_result_data.data["close_invite_limit"] if invoke_result_data.data.__contains__("close_invite_limit") else False
-        invoke_result_data = task_base_model.process_invite_new_user(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, check_user_nick, check_new_user, continue_request_expire, close_invite_limit)
+        invoke_result_data = task_base_model.process_invite_user(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, check_user_nick, check_new_user, continue_request_expire, close_invite_limit)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
