@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2022-05-20 15:43:15
+@LastEditTime: 2022-06-02 11:31:47
 @LastEditors: HuangJianYi
 @Description: 公共handler模块
 """
@@ -590,21 +590,6 @@ class FrameBaseHandler(BaseApiHandler):
                 result = True, f"操作太频繁,请{expire}毫秒后再试"
         return result
 
-    def check_attack_request(self):
-        """
-        :description: 攻击请求校验
-        :return:满足条件直接拦截
-        :last_editors: HuangJianYi
-        """
-        result = False, ""
-        is_filter_attack = config.get_value("is_filter_attack", False)
-        if is_filter_attack == True and self.request_params:
-            for key in self.request_params.keys():
-                if AttackHelper.is_contain_sql(self.request_params[key]) or AttackHelper.is_attack(self.request_params[key]):
-                    result = True, f"参数{key}:值不合法"
-                    break
-        return result
-
     def check_handler_power(self):
         """
         :description: 校验是否有权限访问接口
@@ -669,15 +654,15 @@ class ClientBaseHandler(FrameBaseHandler):
             dict_param = self.get_http_log_extra_dict()
             self._build_http_log(dict_param)
 
+            # 获取设备信息
+            self.device_info_dict = self.get_device_info_dict()
+
             # 记录请求参数明文
             if config.get_value("log_plain", True) == True and self.is_api_encrypt() == True:
                 self.logging_link_info(f"plain_request_params:{self.json_dumps(self.request_params)}")
 
-            # 获取设备信息
-            self.device_info_dict = self.get_device_info_dict()
-
             # 防攻击校验
-            is_attack_request, error_message = self.check_attack_request()
+            is_attack_request, error_message = AttackHelper.check_attack_request()
             if is_attack_request:
                 self.response_json_error("error", error_message)
                 self.finish()
@@ -707,6 +692,7 @@ class ClientBaseHandler(FrameBaseHandler):
                 self.response_json_error("no_power", "没有权限操作")
                 self.finish()
                 return
+                
         except Exception as ex:
             if not hasattr(self, "request_code"):
                 self.request_code = UUIDHelper.get_uuid()
