@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2022-03-09 09:17:57
+@LastEditTime: 2022-05-31 18:05:34
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -1415,10 +1415,10 @@ class TopBaseModel():
             invoke_result_data.success = False
             return invoke_result_data
 
-    def get_crm_point_available(self, user_nick, access_token, app_key, app_secret, is_log=False):
+    def get_crm_point_available(self, mix_nick, access_token, app_key, app_secret, is_log=False):
         """
         :description: 获取店铺会员积分
-        :param user_nick：用户昵称
+        :param mix_nick：混淆昵称
         :param access_token：access_token
         :param app_key:app_key
         :param app_secret:app_secret
@@ -1430,7 +1430,7 @@ class TopBaseModel():
         try:
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.CrmPointAvailableGetRequest()
-            req.buyer_nick = user_nick
+            req.mix_nick = mix_nick
             resp = req.getResponse(access_token)
             if is_log:
                 log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + str(resp) +  "【access_token】：" + access_token + "【获取店铺会员积分】"
@@ -1465,10 +1465,11 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def change_crm_point(self, open_id, change_type, opt_type, quantity, access_token, app_key, app_secret, activity_id=0, activity_name="", is_log=False):
+    def change_crm_point(self, open_id, mix_nick, change_type, opt_type, quantity, access_token, app_key, app_secret, activity_id=0, activity_name="", is_log=False):
         """
         :description: 操作店铺会员积分
         :param open_id：买家open_id
+        :param mix_nick：混淆昵称
         :param change_type：变更类型：0交易，1：互动活动，2：权益兑换，3：手工调整
         :param opt_type：操作类型，0：增加，1：扣减
         :param quantity：积分数量
@@ -1492,7 +1493,10 @@ class TopBaseModel():
             req.change_type = change_type
             req.opt_type = opt_type
             req.quantity = quantity
-            req.open_id = open_id
+            if open_id:
+                req.open_id = open_id
+            if mix_nick:
+                req.mix_nick = mix_nick
             resp = req.getResponse(access_token)
             if is_log:
                 log_info = "【req】:" + SevenHelper.json_dumps(req) + "【resp】:" + str(resp) + "【access_token】：" + access_token + "【操作店铺会员积分】"
